==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/afgifte/v20130701/AfgifteBestandType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.bestand.v20130701.Attachment;


/**
 * <p>Java class for AfgifteBestandType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteBestandType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701}AfgifteType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/bestand/v20130701}Attachment"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteBestandType", propOrder = {
    "attachment"
})
public class AfgifteBestandType
    extends AfgifteType
{

    @XmlElement(name = "Attachment", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/bestand/v20130701", required = true)
    protected Attachment attachment;

    /**
     * Gets the value of the attachment property.
     * 
     * @return
     *     possible object is
     *     {@link Attachment }
     *     
     */
    public Attachment getAttachment() {
        return attachment;
    }

    /**
     * Sets the value of the attachment property.
     * 
     * @param value
     *     allowed object is
     *     {@link Attachment }
     *     
     */
    public void setAttachment(Attachment value) {
        this.attachment = value;
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/afgifte/v20130701/AfgifteBestandType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.bestand.v20130701.Attachment;


/**
 * <p>Java class for AfgifteBestandType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteBestandType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701}AfgifteType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/bestand/v20130701}Attachment"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteBestandType", propOrder = {
    "attachment"
})
public class AfgifteBestandType
    extends AfgifteType
{

    @XmlElement(name = "Attachment", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/bestand/v20130701", required = true)
    protected Attachment attachment;

    /**
     * Gets the value of the attachment property.
     * 
     * @return
     *     possible object is
     *     {@link Attachment }
     *     
     */
    public Attachment getAttachment() {
        return attachment;
    }

    /**
     * Sets the value of the attachment property.
     * 
     * @param value
     *     allowed object is
     *     {@link Attachment }
     *     
     */
    public void setAttachment(Attachment value) {
        this.attachment = value;
    }

}
